@@ -13,16 +13,9 @@ class DefaultMiddleware(Middleware):
 
 class DefaultExceptionHandler:
     def __init__(self, app):
-        self.app = app
-        app.templates_dir = os.abspath("selfpages")
+        self.app = app(templates_dir="selfpages")
 
     def handle_error(self, request, response, error):
         response.status_code = 500
         response.body = self.app.template(
             "error-500.html", context={"error": str(error)})
-
-class TestClass:
-    def __init__(self):
-        self.test()
-    def test(self):
-        print("TEST")
\ No newline at end of file
